@@ -4,11 +4,11 @@ package File::HomeDir::Unix;
 
 use 5.005;
 use strict;
+use Carp ();
 
-# Globals
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '0.54';
+	$VERSION = '0.57';
 }
 
 
